@@ -45,6 +45,7 @@ class LocalRepo(Recycle, _SharedAPI):
         return self.get_metadata_path().exists()
 
     def load_metadata(self):
+        """ Read metadata path and load values. """
         self.has_loaded_metadata = True
 
         if self.get_metadata_path().exists():
@@ -60,6 +61,14 @@ class LocalRepo(Recycle, _SharedAPI):
         if self.name is Ellipsis:
             self.name = self.path.name()
 
+    def get_metadata_dict(self):
+        """ Get current metadata values as a dict. """
+        return {key: str(getattr(self, key)) if key == "version" else getattr(self, key) for key in self.metadata_keys}
+
+    def write_metadata(self):
+        """ Write to metadata path using current metadata values. """
+        self.get_metadata_path().write(self.get_metadata_dict(), overwrite=True)
+
     def exists(self):
         """ Return whether this API's target exists. """
         return self.path_exists(path=self.path)
@@ -69,7 +78,7 @@ class LocalRepo(Recycle, _SharedAPI):
         if path.is_file() or not path.exists():
             return False
         return bool(path.get_child(filt=lambda x: x.name() in ("README.md", ), traverse_excluded=True))
-        # return bool(path.get_child(filt=lambda x: x.name() in ("setup.py", ), traverse_excluded=True))
+        # return bool(path.get_child(filt=lambda x: x.name() in ("setup.py", ), traverse_excluded=True))  # setup.py was not included in pypi's sdist
 
     @classmethod
     def get_repo_path_parent(cls, path=None):
@@ -103,6 +112,9 @@ class LocalRepo(Recycle, _SharedAPI):
         if path and (name is None or name == path.name()):
             return path
 
+        # if Path.get_working_dir().name() == name:
+        #     return Path.get_working_dir()
+
         if name is None:
             name = "generalpackager"
 
@@ -134,7 +146,7 @@ class LocalRepo(Recycle, _SharedAPI):
     def get_license_path(self):     return self.path / "LICENSE"
     def get_workflow_path(self):    return self.path / ".github/workflows/workflow.yml"
     def get_test_path(self):        return self.path / f"{self.name}/test"
-
+    def get_init_path(self):        return self.path / self.name / "__init__.py"
 
     @deco_cache()
     def get_test_paths(self):
@@ -171,6 +183,10 @@ class LocalRepo(Recycle, _SharedAPI):
             Subprocess messed up -e flag compared to doing it in terminal, so use the normal one."""
         subprocess.check_call([sys.executable, "-m", "pip", "install", str(self.path)])
 
+    def pip_uninstall(self):
+        """ Uninstall this repository with pip."""
+        subprocess.check_call([sys.executable, "-m", "pip", "uninstall", "-y", self.name])
+
     def unittest(self):
         """ Run unittests for this repository. """
         subprocess.check_call([sys.executable, "-m", "unittest", "discover", str(self.get_test_path())])
